@@ -20,6 +20,7 @@
  */
 
 #include <config.h>
+#undef GNULIB_POSIXCHECK /* too many complaints for now */
 
 #include "oath.h"
 
@@ -58,9 +59,7 @@ parse_usersfile (const char *username,
 		 FILE * infh,
 		 char **lineptr, size_t * n, uint64_t * new_moving_factor)
 {
-  ssize_t t;
-
-  while ((t = getline (lineptr, n, infh)) != -1)
+  while (getline (lineptr, n, infh) != -1)
     {
       char *saveptr;
       char *p = strtok_r (*lineptr, whitespace, &saveptr);
@@ -162,9 +161,7 @@ update_usersfile2 (const char *username,
 		   char **lineptr,
 		   size_t * n, char *timestamp, uint64_t new_moving_factor)
 {
-  ssize_t t;
-
-  while ((t = getline (lineptr, n, infh)) != -1)
+  while (getline (lineptr, n, infh) != -1)
     {
       char *saveptr;
       char *origline;
@@ -221,7 +218,7 @@ update_usersfile (const char *usersfile,
   {
     int pos;
 
-    pos = fseek (infh, 0L, SEEK_SET);
+    pos = fseeko (infh, 0L, SEEK_SET);
     if (pos == -1)
       return OATH_FILE_SEEK_ERROR;
     clearerr (infh);
